@@ -176,6 +176,11 @@ class Stream(object):
         self.__class__._instances.add(weakref.ref(self))
 
     def start_cache(self, cache_max_len=None, cache_max_age_seconds=None):
+        """
+            缓冲开启
+            cache_max_len 缓存长度
+            cache_max_age_seconds 缓存时间
+        """
         self.is_cache = True
         self.cache_max_len = cache_max_len or 1
         self.cache_max_age_seconds = cache_max_age_seconds or 60 * 5
@@ -531,8 +536,7 @@ class Stream(object):
         """#async等将执行结果入流"""
         assert isinstance(x, gen.Awaitable)
         futs = gen.convert_yielded(x)
-        if not self.loop:
-            self.loop = get_io_loop()
+        self.loop = self.loop or get_io_loop()
         self.loop.add_future(futs, lambda x: self._emit(x.result()))
 
     def __ror__(self, x):  # |
@@ -540,18 +544,17 @@ class Stream(object):
         if isinstance(x, gen.Awaitable):
             self.attend(x)
         else:
-            self.emit(x)
+            self.emit(x, asynchronous=False)
         return x
 
-    def __rrshift__(self, value):  # stream左边的>>
+    def __rrshift__(self, x):  # stream左边的>>
         """emit value to stream ,end,return emit result"""
-        self.emit(value, asynchronous=True)
-        return value
+        # self.emit(value, asynchronous=True)
+        return self.__ror__(x)
 
-    def __lshift__(self, value):  # stream右边的<<
+    def __lshift__(self, x):  # stream右边的<<
         """emit value to stream ,end,return emit result"""
-        self.emit(value)
-        return value
+        return self.__ror__(x)
 
     def catch(self, func):
         """捕获函数执行结果到流内.
@@ -631,13 +634,13 @@ class Stream(object):
         return self.catch(func).__call__ @ P
 
     def __rxor__(self, func):
-        """左边的 ~.，函数异常入流.优先级不高"""
+        """左边的 ^.，函数异常入流.优先级不高"""
         return self.catch_except(func).__call__ @ P
 
     def __rshift__(self, ref):  # stream右边的
         """Stream右边>>,sink到右边的对象.
 
-        支持三种类型:list| text file| stream | callable
+        支持5种类型:list| text file| str | stream | callable
         """
         return match(ref,
                      list, lambda ref: self.sink(ref.append),
@@ -653,6 +656,9 @@ class Stream(object):
                          'list| str | text file| stream | callable')
                      )
 
+    def __getitem__(self, *args):
+        return self.cache.values().__getitem__(*args)
+
     def route(self, occasion):
         """路由函数.
 
@@ -1098,8 +1104,7 @@ def sync(loop, func, *args, **kwargs):
     # This was taken from distrbuted/utils.py
 
     # Tornado's PollIOLoop doesn't raise when using closed, do it ourselves
-    if not loop:
-        loop = get_io_loop()
+    loop = loop or get_io_loop()
     if PollIOLoop\
         and ((isinstance(loop, PollIOLoop)
               and getattr(loop, '_closing', False))
