@@ -1,4 +1,5 @@
-from deva import bus, log, when, Deva
+from deva import bus, log, when, Deva, timer, Stream, print
+# from deva import *
 
 
 # 开盘任务
@@ -18,4 +19,8 @@ def onclose(x):
 when('open', source=bus).then(lambda: print(f'开盘啦'))
 
 
+s = Stream()
+timer(start=True) >> s
+when((lambda x: x % 2 == 0), s).then(lambda x: x >> print)
+
 Deva.run()
