@@ -15,10 +15,9 @@ class RedisStream(Stream):
 
 
     上游进来的写入redis ，redis的读出来的压入下游,
-    写入异步，所以为了避免下游读取消化慢，max_len设置要足够长，防止丢数据
     exapmle::
 
-        news = Stream.RedisStream('news',max_len=1000)
+        news = Stream.RedisStream('news')
         l = list()
         news>>l
         for i in range(1000):
@@ -29,15 +28,12 @@ class RedisStream(Stream):
     """
 
     def __init__(self, topic, start=True,
-                 group=None, max_len=100, address='redis://localhost', db=0, password=None, **kwargs):
+                 group=None, address='localhost', db=0, password=None, **kwargs):
         self.topic = topic
         self.redis_address = address
         self.redis_password = password
-        if not group:
-            group = hash(self)+hash(time.time())
-        self.group = group
+        self.group = group or hash(self)+hash(time.time())
         self.consumer = hash(self)
-        self.max_len = max_len
 
         super(RedisStream, self).__init__(ensure_io_loop=True, **kwargs)
         self.redis = None
@@ -48,10 +44,11 @@ class RedisStream(Stream):
     @gen.coroutine
     def process(self):
         if not self.redis:
-            self.redis = yield aioredis.create_redis(self.redis_address, password=self.redis_password, loop=self.loop)
+            self.redis = yield aioredis.Redis(host=self.redis_address, password=self.redis_password)
 
-        exists = yield self.redis.exists(self.topic)
-        if not exists:
+        topic_exists = yield self.redis.exists(self.topic)
+        if not topic_exists:
+            print('create topic:', self.topic)
             yield self.redis.xadd(self.topic, {'data': dill.dumps('go')})
         try:
             yield self.redis.xgroup_create(self.topic, self.group)
@@ -59,17 +56,18 @@ class RedisStream(Stream):
             print(e)
 
         while True:
-            result = yield self.redis.xread_group(self.group, self.consumer, [self.topic], count=1, latest_ids=['>'])
-            data = dill.loads(result[0][2][b'data'])
-            self._emit(data)
-            if self.stopped:
-                break
+            result = yield self.redis.xread(count=1, block=500, streams={self.topic: '$'})
+            if result:
+                data = dill.loads(result[0][1][0][1][b'data'])
+                self._emit(data)
+                if self.stopped:
+                    break
 
     @gen.coroutine
     def _send(self, data):
         if not self.redis:
-            self.redis = yield aioredis.create_redis(self.redis_address, password=self.redis_password, loop=self.loop)
-        yield self.redis.xadd(self.topic, {'data': dill.dumps(data)}, max_len=self.max_len)
+            self.redis = yield aioredis.Redis(host=self.redis_address, password=self.redis_password)
+        yield self.redis.xadd(self.topic, {'data': dill.dumps(data)})
 
     def emit(self, x, asynchronous=True):
         self.loop.add_callback(self._send, x)
@@ -88,9 +86,9 @@ class RedisStream(Stream):
 @Stream.register_api()
 class Topic(RedisStream):
 
-    def __init__(self, name='', maxsize=None,  **kwargs):
+    def __init__(self, name='', group=str(os.getpid()), maxsize=None,  **kwargs):
         super().__init__(topic=name,
-                         group=str(os.getpid()),
+                         group=group,
                          start=True,
                          name=name,
                          **kwargs)
